@@ -5,7 +5,7 @@ import sys
 import os
 import socket
 import json
-
+from syslog import syslog, LOG_INFO
 from .signalAttachment import Attachment
 from .signalCommon import __type_error__, __socket_receive__, __socket_send__
 from .signalContact import Contact
@@ -86,7 +86,7 @@ class Messages(object):
         if do_load:
             try:
                 self.__load__()
-            except Exception:
+            except RuntimeError:
                 if DEBUG:
                     errorMessage = "warning, creating empy messages: %s" % self._file_path
                     print(errorMessage, file=sys.stderr)
@@ -134,14 +134,14 @@ class Messages(object):
         # Load messages: SentMessage | ReceivedMessage
         self.messages = []
         for message_dict in fromDict['messages']:
-            if message_dict['message_type'] == Message.TYPE_SENT_MESSAGE:
+            if message_dict['messageType'] == Message.TYPE_SENT_MESSAGE:
                 message = SentMessage(command_socket=self._command_socket, account_id=self._account_id,
                                       config_path=self._config_path, contacts=self._contacts, groups=self._groups,
                                       devices=self._devices, this_device=self._this_device,
                                       sticker_packs=self._sticker_packs,
                                       from_dict=message_dict)
 
-            elif message_dict['message_type'] == Message.TYPE_RECEIVED_MESSAGE:
+            elif message_dict['messageType'] == Message.TYPE_RECEIVED_MESSAGE:
                 message = ReceivedMessage(command_socket=self._command_socket, account_id=self._account_id,
                                           config_path=self._config_path, contacts=self._contacts, groups=self._groups,
                                           devices=self._devices, this_device=self._this_device,
@@ -153,11 +153,11 @@ class Messages(object):
         # Load sync messages: GroupUpdate | SyncMessage
         self.sync = []
         for message_dict in fromDict['syncMessages']:
-            if message_dict['message_type'] == Message.TYPE_GROUP_UPDATE_MESSAGE:
+            if message_dict['messageType'] == Message.TYPE_GROUP_UPDATE_MESSAGE:
                 message = GroupUpdate(command_socket=self._command_socket, account_id=self._account_id,
                                       config_path=self._config_path, contacts=self._contacts, groups=self._groups,
                                       devices=self._devices, this_device=self._this_device, from_dict=message_dict)
-            elif message_dict['message_type'] == Message.TYPE_SYNC_MESSAGE:
+            elif message_dict['messageType'] == Message.TYPE_SYNC_MESSAGE:
                 message = SyncMessage(command_socket=self._command_socket, account_id=self._account_id,
                                       config_path=self._config_path, contacts=self._contacts, groups=self._groups,
                                       devices=self._devices, this_device=self._this_device,
@@ -234,7 +234,7 @@ class Messages(object):
             error_message = "Invalid reaction cannot parse."
             raise RuntimeError(error_message)
         # Find the message that was reacted to:
-        reactedMessage = None
+        reactedMessage: Optional[SentMessage | ReceivedMessage | Message] = None
         for message in search_messages:
             if message.sender == reaction.target_author:
                 if message.timestamp == reaction.target_timestamp:
@@ -365,7 +365,7 @@ class Messages(object):
              author: Contact,
              timestamp: Timestamp,
              conversation: Contact | Group,
-             ) -> Optional[SentMessage | ReceivedMessage]:
+             ) -> Optional[SentMessage | ReceivedMessage | Message]:
         """
         Get a message, given an author, a timestamp, and a conversation.
         :param author: Contact: The author of the message we're looking for.
@@ -376,13 +376,13 @@ class Messages(object):
                                 conversation os not a Contact or Group object.
         """
         # Validate  author:
-        target_author: Contact
+        target_author: Optional[Contact] = None
         if isinstance(author, Contact):
             target_author = author
         else:
             __type_error__("author", "Contact", author)
         # Validate recipient:
-        target_conversation: Contact | Group
+        target_conversation: Optional[Contact | Group] = None
         if isinstance(conversation, Contact):
             target_conversation = conversation
         elif isinstance(conversation, Group):
@@ -390,7 +390,7 @@ class Messages(object):
         else:
             __type_error__("recipient", "Contact | Group", conversation)
         # Validate timestamp:
-        targetTimestamp: Timestamp
+        targetTimestamp: Optional[Timestamp] = None
         if isinstance(timestamp, Timestamp):
             targetTimestamp = timestamp
         else:
@@ -402,7 +402,7 @@ class Messages(object):
                 return message
         return None
 
-    def get_quoted(self, quote: Quote) -> Optional[SentMessage | ReceivedMessage]:
+    def get_quoted(self, quote: Quote) -> Optional[SentMessage | ReceivedMessage | Message]:
         """
         Get a message that contains a given Quote.
         :param quote: Quote: The quote we're looking for.
@@ -459,7 +459,9 @@ class Messages(object):
                      quote: Optional[Quote] = None,
                      sticker: Optional[Sticker] = None,
                      preview: Optional[Preview] = None,
-                     ) -> tuple[tuple[bool, Contact | Group, str | SentMessage]]:
+                     ) -> tuple[
+        tuple[bool, Contact, str] | tuple[bool, Contact | Group, str] | tuple[bool, Contact, SentMessage] | tuple[
+            bool, Contact, object], ...]:
         """
         Send a message.
         :param recipients: Iterable[Contact | Group] | Contact | Group: The recipients of the message.
@@ -482,7 +484,7 @@ class Messages(object):
                                 list.
         """
         # Validate recipients:
-        recipient_type: str
+        recipient_type: str = ''
         target_recipients: list[Contact | Group] = []
         if isinstance(recipients, Contact):
             recipient_type = 'contact'
@@ -580,7 +582,7 @@ class Messages(object):
         # Create send message command object:
         send_command_obj = {
             "jsonrpc": "2.0",
-            "contact_id": 2,
+            "id": 2,
             "method": "send",
             "params": {
                 "account": self._account_id,
@@ -638,7 +640,11 @@ class Messages(object):
         response_str = __socket_receive__(self._command_socket)
         # Parse response:
         response_obj: dict[str, object] = json.loads(response_str)
-        # print(responseObj)
+        # Mark system as finished sending
+        self._sending = False
+        #***********************DEBUG:**************************************
+        debug_message = "DEBUG: response_obj = '%s'" % str(response_obj)
+        syslog(LOG_INFO, debug_message)
         # Check for error:
         if 'error' in response_obj.keys():
             error_message = "ERROR: failed to send message, signal error. Code: %i Message: %s" % (
@@ -646,16 +652,15 @@ class Messages(object):
                 response_obj['error']['message'])
             if DEBUG:
                 print(error_message, file=sys.stderr)
-                self._sending = False
-                return_value = []
-                for recipient in target_recipients:
-                    if recipient_type == 'group':
-                        for member in group.members:
-                            return_value.append((False, member, error_message))
-                    else:
-                        return_value.append((False, recipient, error_message))
-                return_value = tuple(return_value)
-                return tuple(return_value)
+            return_value = []
+            for recipient in target_recipients:
+                if recipient_type == 'group':
+                    for member in recipient.members:
+                        return_value.append((False, member, error_message))
+                else:
+                    return_value.append((False, recipient, error_message))
+            return_value = tuple(return_value)
+            return return_value
         # Some messages sent, some may have failed.
         results_list: list[dict[str, object]] = response_obj['result']['results']
         # Gather timestamp:
@@ -693,11 +698,12 @@ class Messages(object):
                     return_value.append((False, contact, result['type']))
             self._sending = False
             return tuple(return_value)
+        # Recipient type == Contact
         else:
             for result in results_list:
                 # Gather contact:
                 contact_id = result['recipientAddress']['number']
-                if contact_id is None:
+                if contact_id is None or contact_id == '':
                     contact_id = result['recipientAddress']['uuid']
                 added, contact = self._contacts.__get_or_add__("<UNKNOWN-CONTACT>", contact_id)
 
@@ -706,18 +712,16 @@ class Messages(object):
                     # Create sent message
                     sent_message = SentMessage(command_socket=self._command_socket, account_id=self._account_id,
                                                config_path=self._config_path, contacts=self._contacts,
-                                               groups=self._groups,
-                                               devices=self._devices, this_device=self._this_device,
-                                               sticker_packs=self._sticker_packs, recipient=contact,
-                                               timestamp=timestamp, body=body, attachments=target_attachments,
-                                               mentions=target_mentions, quote=quote, sticker=sticker, is_sent=True,
-                                               sent_to=target_recipients, preview=preview)
+                                               groups=self._groups, devices=self._devices,
+                                               this_device=self._this_device, sticker_packs=self._sticker_packs,
+                                               recipient=contact, timestamp=timestamp, body=body,
+                                               attachments=target_attachments, mentions=target_mentions, quote=quote,
+                                               sticker=sticker, is_sent=True, sent_to=target_recipients,
+                                               preview=preview)
                     return_value.append((True, contact, sent_message))
                     self.append(sent_message)
                     self.__save__()
                 # Message failed to send:
                 else:
                     return_value.append((False, contact, result['type']))
-            # Mark sending finished.
-            self._sending = False
             return tuple(return_value)
