@@ -96,9 +96,9 @@ class Receipt(Message):
         # Load receipt type:
         if receipt_message['isDelivery']:
             self.receiptType = self.TYPE_DELIVERY
-        elif receipt_message['is_read']:
+        elif receipt_message['isRead']:
             self.receiptType = self.TYPE_READ
-        elif receipt_message['is_viewed']:
+        elif receipt_message['isViewed']:
             self.receiptType = self.TYPE_VIEWED
         else:
             errorMessage = "Unknown receipt type... receiptMessage= %s" % str(receipt_message)
@@ -119,7 +119,7 @@ class Receipt(Message):
         if self.when is not None:
             receipt_dict['when'] = self.when.__to_dict__()
         # Store receipt type:
-        receipt_dict['receipt_type'] = self.receiptType
+        receipt_dict['receiptType'] = self.receiptType
         # Store target timestamps:
         receipt_dict['timestamps'] = []
         for timestamp in self.timestamps:
@@ -133,7 +133,7 @@ class Receipt(Message):
         if from_dict['when'] is not None:
             self.when = Timestamp(from_dict=from_dict['when'])
         # Load receipt Type:
-        self.receiptType = from_dict['receipt_type']
+        self.receiptType = from_dict['receiptType']
         # Load target timestamps:
         self.timestamps = []
         for timestampDict in from_dict['timestamps']:
